#
# spec file for package kf6-kquickcharts
#
# Copyright (c) 2025 SUSE LLC
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via https://bugs.opensuse.org/
#


%define qt6_version 6.8.0

%define rname kquickcharts
# Full KF6 version (e.g. 6.15.0)
%{!?_kf6_version: %global _kf6_version %{version}}
%bcond_without released
Name:           kf6-kquickcharts
Version:        6.15.0
Release:        1.1
Summary:        Set of charts for QtQuick applications
License:        LGPL-2.1-or-later
URL:            https://www.kde.org
Source:         %{rname}-%{version}.tar.xz
%if %{with released}
Source1:        %{rname}-%{version}.tar.xz.sig
Source2:        frameworks.keyring
%endif
BuildRequires:  kf6-extra-cmake-modules >= %{_kf6_version}
BuildRequires:  cmake(KF6KirigamiPlatform) >= %{_kf6_version}
BuildRequires:  cmake(Qt6Qml) >= %{qt6_version}
BuildRequires:  cmake(Qt6Quick) >= %{qt6_version}
BuildRequires:  cmake(Qt6QuickControls2) >= %{qt6_version}
BuildRequires:  cmake(Qt6ShaderTools) >= %{qt6_version}
BuildRequires:  cmake(Qt6ToolsTools) >= %{qt6_version}
Requires:       kf6-kirigami-imports >= %{_kf6_version}
Requires:       qt6-declarative-imports >= %{qt6_version}

%description
The Quick Charts module provides a set of charts that can be used from QtQuick
applications. They are intended to be used for both simple display of data as
well as continuous display of high-volume data (often referred to as plotters).
The charts use a system called distance fields for their accelerated rendering,
which provides ways of using the GPU for rendering 2D shapes without loss of
quality.

%package devel
Summary:        Header files for kquickcharts, a set of charts for QtQuick applications
Requires:       kf6-kquickcharts >= %{version}

%description devel
Development files for KQuickCharts, a set of charts that can be used from QtQuick
applications.

%prep
%autosetup -p1 -n %{rname}-%{version}

%build
%cmake_kf6

%kf6_build

%install
%kf6_install

%ldconfig_scriptlets

%files
%license LICENSES/*
%doc README.md
%{_kf6_debugdir}/kquickcharts.categories
%{_kf6_libdir}/libQuickCharts.so.*
%{_kf6_libdir}/libQuickChartsControls.so.*
%{_kf6_qmldir}/org/kde/quickcharts/

%files devel
%{_kf6_cmakedir}/KF6QuickCharts/
%{_kf6_libdir}/libQuickCharts.so
%{_kf6_libdir}/libQuickChartsControls.so

%changelog
* Mon Jun  9 2025 Christophe Marin <christophe@krop.fr>
- Update to 6.15.0
  * New feature release
  * For more details please see:
  * https://kde.org/announcements/frameworks/6/6.15.0
- Changes since 6.14.0:
  * Consistently name qdoc-related files
  * Update dependency version to 6.15.0
  * Port controls module to QDoc
  * Remove mentions of ValueHistorySource and ModelHistorySource
  * Remove dead code
  * Add tags file to documentation
  * Add missing qhp projects
  * Add landing page for QDoc
  * Port API documentation to QDoc syntax
  * Add missing QML module dependency
  * Update version to 6.15.0
- Replace _kf6_bugfix_version usage
* Sun May  4 2025 Christophe Marin <christophe@krop.fr>
- Update to 6.14.0
  * New feature release
  * For more details please see:
  * https://kde.org/announcements/frameworks/6/6.14.0
- Changes since 6.13.0:
  * Update dependency version to 6.14.0
  * Update version to 6.14.0
* Sat Apr  5 2025 Christophe Marin <christophe@krop.fr>
- Update to 6.13.0
  * New feature release
  * For more details please see:
  * https://kde.org/announcements/frameworks/6/6.13.0
- Changes since 6.12.0:
  * It compiles fine without qt6.9 deprecated methods
  * controls: Use implicit size for layout calculations in AxisLabels
  * controls: Use polish in AxisLabels instead of custom relayout queueing
  * Update dependency version to 6.13.0
* Tue Mar 11 2025 Christophe Marin <christophe@krop.fr>
- Update to 6.12.0
  * New feature release
  * For more details please see:
  * https://kde.org/announcements/frameworks/6/6.12.0
- Changes since 6.11.0:
  * Update dependency version to 6.12.0
  * Update version to 6.12.0
* Sat Feb  8 2025 Christophe Marin <christophe@krop.fr>
- Update to 6.11.0
  * New feature release
  * For more details please see:
  * https://kde.org/announcements/frameworks/6/6.11.0
- Changes since 6.10.0:
  * Update dependency version to 6.11.0
  * Add xml/yaml linting
  * CI: Add linux-qt6-next build
  * Update version to 6.11.0
* Thu Jan  9 2025 Christophe Marin <christophe@krop.fr>
- Update to 6.10.0
  * New feature release
  * For more details please see:
  * https://kde.org/announcements/frameworks/6/6.10.0
- Changes since 6.9.0:
  * Update dependency version to 6.10.0
  * Remove unimplemented methods
  * Update version to 6.10.0
* Sun Dec  8 2024 Christophe Marin <christophe@krop.fr>
- Update to 6.9.0
  * New feature release
  * For more details please see:
  * https://kde.org/announcements/frameworks/6/6.9.0
- Changes since 6.8.0:
  * Update dependency version to 6.9.0
  * Bump KF and QT versions in ecm_set_disabled_deprecation_versions
  * Update version to 6.9.0
* Mon Nov  4 2024 Christophe Marin <christophe@krop.fr>
- Update to 6.8.0
  * New feature release
  * For more details please see:
  * https://kde.org/announcements/frameworks/6/6.8.0
- Changes since 6.7.0:
  * Update dependency version to 6.8.0
  * Update version to 6.8.0
  * Add CI for static builds on Linux
  * Correctly install static QML modules
* Mon Oct  7 2024 Christophe Marin <christophe@krop.fr>
- Update to 6.7.0
  * New feature release
  * For more details please see:
  * https://kde.org/announcements/frameworks/6/6.7.0
- Changes since 6.6.0:
  * Update dependency version to 6.7.0
  * Update version to 6.7.0
* Sat Sep  7 2024 Christophe Marin <christophe@krop.fr>
- Update to 6.6.0
  * New feature release
  * For more details please see:
  * https://kde.org/announcements/frameworks/6/6.6.0
- Changes since 6.5.0:
  * Update version to 6.6.0
  * ci: add Alpine/musl job
* Mon Aug  5 2024 Christophe Marin <christophe@krop.fr>
- Update to 6.5.0
  * New feature release
  * For more details please see:
  * https://kde.org/announcements/frameworks/6/6.5.0
- Changes since 6.4.0:
  * Update dependency version to 6.5.0
  * Update version to 6.5.0
* Tue Jul  9 2024 Christophe Marin <christophe@krop.fr>
- Update to 6.4.0
  * New feature release
  * For more details please see:
  * https://kde.org/announcements/frameworks/6/6.4.0
- Changes since 6.3.0:
  * controls: Don't use visible for hiding text in LegendDelegate
  * controls/legenddelegate: Always hide name if its width is 0
* Wed Jun  5 2024 Christophe Marin <christophe@krop.fr>
- Update to 6.3.0
  * New feature release
  * For more details please see:
  * https://kde.org/announcements/frameworks/6/6.3.0/
- Changes since 6.2.0:
  * Set a better default size for the example application
  * Don't crash if we try to access an item from an empty ArraySource
  * Enable highlighting for most pages in the charts example
  * Port example pages to use ChartPage
  * Add a common base type for pages in the chart example
  * Remove API selection from charts example
  * Convert chart example to use an executable QML module
  * Expose highlight property on PieChartControl
  * Support highlighting in LineChartControl
  * controls: Add support for highlighting hovered items in Legend
  * Fix normalized line size calculation in LineChartNode
  * Support highlight in BarChart
  * Support highlight in PieChart
  * Support highlight property in LineChart
  * Add a protected method to Chart to deemphasise non-highlighted items
  * Add a `highlight` property to Chart
  * Remove explicit maintainer from metainfo
  * controls: Ceil all components of preferredWidth in LegendDelegate contents (kde#486411)
* Mon May  6 2024 Christophe Marin <christophe@krop.fr>
- Update to 6.2.0
  * New feature release
  * For more details please see:
  * https://kde.org/announcements/gear/6.2.0/
- No code change since 6.1.0
* Fri Apr  5 2024 Christophe Marin <christophe@krop.fr>
- Update to 6.1.0
  * New feature release
- Changes since 6.0.0:
  * update version for new release
  * Declare QML module dependencies
  * Generate default set of GLSL shaders (kde#482988)
  * examples: Remove separator from main page list items
  * piechartnode: Rename updateTriangles to updateSegments
  * piechartnode: Remove some unused stuff
  * examples: Change "smooth" to "interpolate"
  * piechart: Use the right amount of thickness for the chart
  * linechart: Use fwidth of the point instead of sdf to avoid conditional fwidth (kde#434462)
  * sdf: Allow specifying fwidth() to sdf_render()
* Wed Feb 21 2024 Fabian Vogt <fabian@ritter-vogt.de>
- Update to 6.0.0
  * New bugfix release
  * Release announcement not available yet
- Changes since 5.249.0:
  * update version for new release
* Wed Jan 31 2024 Fabian Vogt <fabian@ritter-vogt.de>
- Update to 5.249.0 (6.0 RC 2):
  * New bugfix release
  * For more details see https://kde.org/announcements/megarelease/6/rc2/
* Mon Jan 15 2024 Fabian Vogt <fabian@ritter-vogt.de>
- Update to 5.248.0 (6.0 RC 1)
  * For more details please see:
    https://kde.org/announcements/megarelease/6/rc1/
* Sat May 27 2023 Christophe Marin <christophe@krop.fr>
- Init kf6-kquickcharts
